# Liku

Python HTML templating, inspired by modern Web Development.

Read the docs: https://rorre.github.io/liku

## Examples

Examples available at [examples directory](https://github.com/rorre/liku/tree/main/examples)
